@@ -47,10 +47,16 @@ def download(model=None):
         "/data/gpt2/labels_dict_gpt.csv":"https://www.dropbox.com/s/hbxs4hp5v2y2i96/labels_dict_gpt.csv?dl=1",
         "/data/gpt2/nyt-theme-tags.csv":"https://www.dropbox.com/s/c1wts9knu3htzch/nyt-theme-tags.csv?dl=1",
         # distilbert model
+        "/data/distilbert/labels_dict_distilbert.csv":"https://www.dropbox.com/s/1l5hdzfz7xoqgaq/labels_dict_distilbert.csv?dl=1",
+        "/data/distilbert/nyt-theme-tags.csv":"https://www.dropbox.com/s/omgstbndd3xl4cy/nyt-theme-tags.csv?dl=1",
         # ensemble model
-        "/data/ensemble/model_quadsemble.h5":"https://www.dropbox.com/s/5q68l8zx2h2gbc6/model_quadsemble.h5?dl=1",
-        "/data/ensemble/labeldict.p":"https://www.dropbox.com/s/smrsyx96hf9nt9d/labelsdict.p?dl=1",
-        "/data/ensemble/nyt-theme-tags.csv":"https://www.dropbox.com/s/smrsyx96hf9nt9d/labelsdict.p?dl=1",
+
+        # trisemble model
+
+        # quadsemble model
+        "/data/quadsemble/model_quadsemble.h5":"https://www.dropbox.com/s/ng94kufjtobl3uw/model_quadsemble.h5?dl=1",
+        "/data/quadsemble/labeldict.p":"https://www.dropbox.com/s/sv14u7mwe2wnn49/labelsdict.p?dl=1",
+        "/data/quadsemble/nyt-theme-tags.csv":"https://www.dropbox.com/s/m94w28knnv2gcq9/nyt-theme-tags.csv?dl=1",
     }
 
     # get package directory
@@ -68,6 +74,10 @@ def download(model=None):
         "/data/tfidf_bi",
         "/data/doc2vec",
         "/data/gpt2",
+        "/data/distilbert",
+        "/data/ensemble",
+        "/data/trisemble",
+        "/data/quadsemble",
     ]
     for dir in dirs:
         if (model is None or model == dir.split("/")[-1]):
